/**
 * OW2 Util
 * Copyright (C) 2008-2009 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: IJaxwsWebServiceRef.java 4672 2009-02-20 15:24:30Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.api.struct;

import java.io.Serializable;
import java.util.List;

import org.ow2.util.ee.metadata.common.api.xml.struct.IHandlerChains;
import org.ow2.util.ee.metadata.common.api.xml.struct.IPortComponentRef;

/**
 * Manage WebServiceRef metadata.
 * @author Guillaume Sauthier
 */
public interface IJaxwsWebServiceRef extends Serializable {

    /**
     * @return A product specific name that this resource should be mapped to.
     */
    String getMappedName();

    /**
     * A product specific name that this resource should be mapped to.
     * @param mappedName product specific name
     */
    void setMappedName(String mappedName);

    /**
     * @return The JNDI name of the resource.
     */
    String getName();

    /**
     * The JNDI name of the resource.
     * @param name JNDI name
     */
    void setName(String name);

    /**
     * @return The Java type of the resource.
     */
    String getType();

    /**
     * The Java type of the resource.
     * @param type Java type
     */
    void setType(String type);

    /**
     * The service class, always a type extending javax.xml.ws.Service. This element
     * must be specified whenever the type of the reference is a service endpoint interface.
     * @return The service class, always a type extending javax.xml.ws.Service
     */
    String getValue();

    /**
     * This element must be specified whenever the type of the reference is a
     * service endpoint interface.
     * @param value The service class, always a type extending javax.xml.ws.Service
     */
    void setValue(String value);

    /**
     * @return A URL pointing to the WSDL document for the web service.
     */
    String getWsdlLocation();

    /**
     * A URL pointing to the WSDL document for the web service.
     * If not specified, the WSDL location specified by annotations on the resource
     * type is used instead.
     * @param wsdlLocation Absolute URL or relative URL (to the module)
     */
    void setWsdlLocation(String wsdlLocation);

    /**
     * Store the value of the @HandlerChain.file attribute which is collocated
     * with this @WebServiceRef.
     * @param fileAttribute attribute's value
     */
    void setHandlerChainFile(String fileAttribute);

    /**
     * @return the value of the @HandlerChain.file attribute.
     */
    String getHandlerChainFile();

    /**
     * Stores an Object representation of a handler-chains defined in standard descriptors.
     * @param handlerChains handler-chains as Object.
     */
    void setHandlerChains(IHandlerChains handlerChains);

    /**
     * @return the value of the handler-chains Object representation.
     */
    IHandlerChains getHandlerChains();

    /**
     * Stores all port component refs.
     * @param portComponentRefs list of port component ref.
     */
    void setPortComponentRefs(List<IPortComponentRef> portComponentRefs);

    /**
     * @return the value of the list of port component refs.
     */
    List<IPortComponentRef> getPortComponentRefs();

    /**
     * Gets a port component ref by providings its service endpoint interface.
     * @param serviceEndpointInterface the given SEI
     * @return a port component ref or null if not found
     */
    IPortComponentRef getPortComponentRef(String serviceEndpointInterface);

    /**
     * @param declaringClassname Class declaring the @HandlerChain annotation.
     */
    void setDeclaringClass(String declaringClassname);

    /**
     * @return Name of the class declaring the @HandlerChain annotation (will be
     *         null if no @HC annotation is present).
     */
    String getDeclaringClass();


}
